Description Usage Arguments Value
View source: R/performanceTable_heatmap.R
This is a convenient visualisation that shows the (weighed) estimates for each decision/criterion combination. Decisions are sorted alphabetically and criteria are sorted alphabetically within their clusters, which are also sorted alphabetically.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 | performanceTable_heatmap(
weighedEstimates,
estimateCol,
scenario_id,
scenario_label = scenario_id,
criterionOrder = NULL,
decisionOrder = NULL,
criterionLabels = NULL,
decisionLabels = NULL,
alternativeLabels = NULL,
useDecisionAlternativeLabels = TRUE,
decision_alternative_pre = "**",
decision_alternative_sep = "**:<br />",
decision_alternative_suf = "",
criterionId_col = mdmcda::opts$get("criterionId_col"),
parentCriterionId_col = mdmcda::opts$get("parentCriterionId_col"),
criterionLabel_col = mdmcda::opts$get("criterionLabel_col"),
decisionId_col = mdmcda::opts$get("decisionId_col"),
decisionLabel_col = mdmcda::opts$get("decisionLabel_col"),
alternativeValue_col = mdmcda::opts$get("alternativeValue_col"),
alternativeLabel_col = mdmcda::opts$get("alternativeLabel_col"),
scenarioId_col = mdmcda::opts$get("scenarioId_col"),
theme = ggplot2::theme_minimal(base_size = mdmcda::opts$get("ggBaseSize"))
)
|
weighedEstimates |
A 'weighedEstimates' data frame as produced by [mdmcda::weigh_estimates()]. |
estimateCol |
The name of the column with the estimates. |
scenario_id, scenario_label |
The identifier and label of the scenario to create the heatmap for. |
criterionOrder, decisionOrder |
Optionally, vectors with criterion and decision identifiers to indicate the order that should be used. |
criterionLabels, decisionLabels |
Optionally, named vectors with labels for the criteria and decisions. These have to be named vectors, with the elements being the labels, and the names the identifiers. |
alternativeLabels |
The 'alternativeLabels' object; optionally, to override the alternative labels in the 'weighedEstimates' object. |
useDecisionAlternativeLabels |
Whether to label the decision plot with the decisions or combined labels that also include the alternative for the scenario. |
decision_alternative_pre, decision_alternative_sep, decision_alternative_suf |
If 'useDecisionAlternativeLabels' is 'TRUE', these prefix, separator, and suffix are used to compose the decision plot labels. |
criterionId_col, parentCriterionId_col, criterionLabel_col, decisionId_col, decisionLabel_col, alternativeValue_col, alternativeLabel_col, alternativeLabel_col, scenarioId_col |
The column names in the 'weighedEstimates' data frame. |
theme |
The 'ggplot2' theme to use. |
A 'ggplot2' plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.