scoreBarchart_criteriaCluster: Create a bar chart with scores per criteria cluster

Description Usage Arguments Value

View source: R/scoreBarchart_criteriaCluster.R

Description

Create a bar chart with scores per criteria cluster

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
scoreBarchart_criteriaCluster(
  weighedEstimates,
  estimateCol,
  parentCriterionOrder = unique(weighedEstimates$parentCriterion_id),
  parentCriterionLabels = parentCriterion_ids,
  scenarioOrder = unique(weighedEstimates$scenario_id),
  scenarioLabels = scenario_ids,
  strokeColor = "black",
  strokeSize = 0.1,
  title = "MDMCDA criteria cluster bar chart",
  xLab = "Criteria Cluster",
  yLab = estimateCol,
  theme = ggplot2::theme_minimal(base_size = mdmcda::opts$get("ggBaseSize")),
  guides = ggplot2::guide_legend(nrow = 1),
  legend.position = "top"
)

Arguments

weighedEstimates

A 'weighedEstimates' object.

estimateCol

The column name with the estimates to use.

strokeColor, strokeSize

The color and pen width of the stroke.

title, xLab, yLab

The title and x and y axis labels.

theme

The 'ggplot2' theme to use.

guides

A guides argument to tweak the legend.

legend.position, legend.box.margin

The position and spacing for the legend.

parentCriterion_ids

The parent criteria to include.

parentCriterion_labels

The labels for the parent criteria.

scenario_ids

The scenarios to include.

scenario_labels

The labels for the scenarios.

Value

A 'ggplot2' plot.


Matherion/mdmcda documentation built on Dec. 31, 2020, 3:13 p.m.